==> V01.82.zip: tweet_live-V01.82/web/edito-datacuration/config.php <==
<?php
$config = array(
   	'hashtag'    => '#edito11',
   	'date'   => '16.02.2012',
   	'heure'   => '17h30-20h00',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Nouvelles formes d'éditorialisation",
	'abstract'   => "Séminaire &laquo;&nbsp;nouvelles formes d'éditorialisation&nbsp;&raquo;&nbsp;:<br /><b>Datacuration, agrégation, et moteurs de recherche</b><br/>le 16/02/2012 de 17h30 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<h3>Datacuration, agrégation, et moteurs de recherche</h3>
   	<p>le 16/02/2012 de 17h30 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite</p>
    
    <p>Invités :</p>
    <ul>
        <li><b>Bertrand Delezoide</b>, Chercheur au CEA</li>
        <li><b>Emmanuel Benazera</b>, Directeur de <a href=\"http://www.seeks.pro\" target=\"_blank\">Seeks</a> et fondateur du projet libre <a href=\"http://www.seeks-project.info\" target=\"_blank\">Seeks Project</a></li>
        <li><b>Nicolas Loubet</b>, Directeur associé à <a href=\"http://www.umaps.fr\" target=\"_blank\">Umaps</a> et Social Media Designer à <a href=\"http://www.knowtex.com\" target=\"_blank\">Knowtex</a></li>
        <li>La séance sera introduite par <b>Yannick Maignien</b>.</li>
    </ul>
    <p>Les contenus dépendent souvent moins des données publiées par un auteur que des nouvelles formes d’édition, c’est-à-dire de réutilisation des données, par agrégation ou par requête au terme d’actions automates de différents algorithmes, imposant peu à peu une économie du lien sur une économie du contenu.</p>
    <p>Ce séminaire présentera tout d’abord un rapide benchmark des différentes solutions d’agrégation se différenciant chacune par un paradigme propre (le hashtag, la communauté, le layout, le live, etc.), et dont les contraintes et limites soulèvent quelques questions en termes de production de savoir.</p>
    <p>Nous nous pencherons ensuite sur les techniques utilisées actuellement par les moteurs de recherche pour agréger et éditorialiser les contenus.</p>
    <p>Enfin, un coup de projecteur sur le moteur de recherche peer-to-peer Seeks.fr, proposant une nouvelle rupture de paradigme pour la recherche et l’agrégation.</p>",
   	'link' => 'http://seminaire.sens-public.org',
   	'islive'     => true,
   	//'flv_provider' => 'rtmp',
	//'flv_file' => 'livestream',
	//'flv_streamer' => 'rtmp://media.iri.centrepompidou.fr/ddc-player',
    'use_tweetcast' => true,
	//'knowtex_url' => "http://labs.knowtex.com/enmi2011/?mapOnly#carto",
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-editorialisation.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-editorialisation.jpg', // 270 × 150 pixels

 	'archive_title' => "Datacuration, agrégation, et moteurs de recherche",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 16 février 2012 17:30 - 19:30',

    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/5510ecc4-5565-11e1-ac23-00145ea49a02",
	'duration'   => 6640378,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
);

==> V06.003.zip: tweet_live-V06.003/web/edito-datacuration/config.php <==
<?php
$config = array(
   	'hashtag'    => '#edito11',
   	'date'   => '16.02.2012',
   	'heure'   => '17h30-20h00',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Nouvelles formes d'éditorialisation",
	'abstract'   => "Séminaire &laquo;&nbsp;nouvelles formes d'éditorialisation&nbsp;&raquo;&nbsp;:<br /><b>Datacuration, agrégation, et moteurs de recherche</b><br/>le 16/02/2012 de 17h30 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<h3>Datacuration, agrégation, et moteurs de recherche</h3>
   	<p>le 16/02/2012 de 17h30 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite</p>
    
    <p>Invités :</p>
    <ul>
        <li><b>Bertrand Delezoide</b>, Chercheur au CEA</li>
        <li><b>Emmanuel Benazera</b>, Directeur de <a href=\"http://www.seeks.pro\" target=\"_blank\">Seeks</a> et fondateur du projet libre <a href=\"http://www.seeks-project.info\" target=\"_blank\">Seeks Project</a></li>
        <li><b>Nicolas Loubet</b>, Directeur associé à <a href=\"http://www.umaps.fr\" target=\"_blank\">Umaps</a> et Social Media Designer à <a href=\"http://www.knowtex.com\" target=\"_blank\">Knowtex</a></li>
        <li>La séance sera introduite par <b>Yannick Maignien</b>.</li>
    </ul>
    <p>Les contenus dépendent souvent moins des données publiées par un auteur que des nouvelles formes d’édition, c’est-à-dire de réutilisation des données, par agrégation ou par requête au terme d’actions automates de différents algorithmes, imposant peu à peu une économie du lien sur une économie du contenu.</p>
    <p>Ce séminaire présentera tout d’abord un rapide benchmark des différentes solutions d’agrégation se différenciant chacune par un paradigme propre (le hashtag, la communauté, le layout, le live, etc.), et dont les contraintes et limites soulèvent quelques questions en termes de production de savoir.</p>
    <p>Nous nous pencherons ensuite sur les techniques utilisées actuellement par les moteurs de recherche pour agréger et éditorialiser les contenus.</p>
    <p>Enfin, un coup de projecteur sur le moteur de recherche peer-to-peer Seeks.fr, proposant une nouvelle rupture de paradigme pour la recherche et l’agrégation.</p>",
   	'link' => 'http://seminaire.sens-public.org',
   	'islive'     => true,
    'use_tweetcast' => true,
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-editorialisation.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-editorialisation.jpg', // 270 × 150 pixels

 	'archive_title' => "Datacuration, agrégation, et moteurs de recherche",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 16 février 2012 17:30 - 19:30',

    // After the event
	'metadata'    => "5510ecc4-5565-11e1-ac23-00145ea49a02",
	'duration'   => 6640378,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
);
